@@ -1,12 +1,11 @@
 import atexit
+import csv
 import glob
 import json
 import logging
 import os
-import shutil
 import sys
 import tkinter as tk
-import threading
 import unicodedata
 from tkinter import filedialog, messagebox
 
@@ -71,8 +70,6 @@ class LabelOcrApp:
         self.btn_lower = builder.get_object("btn_lower")
         self.lower_case = False
 
-
-
         self.progress_label = builder.get_variable("var_progress_label")
 
         self.list_file = None
@@ -98,14 +95,16 @@ class LabelOcrApp:
 
     def load_data(self):
         if self.image_dir.get() is not None and self.label_path.get() is not None and len(
-                self.image_dir.get()) > 0 and len(self.label_path.get()) > 0 and os.path.exists(self.image_dir.get()) and os.path.exists(self.label_path.get()):
+                self.image_dir.get()) > 0 and len(self.label_path.get()) > 0 and os.path.exists(
+            self.image_dir.get()) and os.path.exists(self.label_path.get()):
             if self.label_in_filename:
                 self.list_file = list(glob.glob(f"{self.image_dir.get()}/*.png"))
                 self.list_label = [os.path.splitext(os.path.basename(file))[0] for file in self.list_file]
                 self.list_label = [self._parse_label(x) for x in self.list_label]
             else:
                 df_label = pd.read_csv(self.label_path.get(), header=0,
-                                       dtype={"filename": object, "label": object}, keep_default_na=False, na_values=[''])
+                                       dtype={"filename": object, "label": object}, keep_default_na=False,
+                                       na_values=[''])
                 self.list_file = df_label['filename'].tolist()
                 self.list_label = df_label['label'].tolist()
                 if 'conf' in df_label.columns:
@@ -132,9 +131,9 @@ class LabelOcrApp:
             if self.list_score is not None:
                 data['conf'] = self.list_score
             df = pd.DataFrame(data)
-            df.to_csv(self.label_path.get(), index=False)
+            df.to_csv(self.label_path.get(), index=False, quoting=csv.QUOTE_ALL)
 
-    def _get_next_idx(self, is_next=True)->int:
+    def _get_next_idx(self, is_next=True) -> int:
         current_idx = self.index
         step = 1 if is_next else -1
         if self.list_score is None:
@@ -442,4 +441,4 @@ def main():
     app.run()
 
 
-main()
\ No newline at end of file
+main()
